<?php
if (!current_user_can('manage_options')) {
    wp_die('Unauthorized');
}

$files = [
    plugin_dir_path(__FILE__) . 'send-report.php',
    plugin_dir_path(__FILE__) . 'report-hwp.php',
    plugin_dir_path(__FILE__) . 'send-form.php',
    plugin_dir_path(__FILE__) . 'index.php',
];

define('API_KEY_MASK', '********************');

$oldDomain = '';
$matchFound = false;
$success = false;

foreach ($files as $file) {
    if (file_exists($file)) {
        $content = file_get_contents($file);
        if (preg_match('/fetch\(["\']https?:\/\/([^\/]+)\//', $content, $matches)) {
            $oldDomain = $matches[1];
            $matchFound = true;
            break;
        }
    }
}

$savedApiKey = get_option('htfy_pusher_api_key', '');

// Handle POST
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['new_domain'])) {
        $newDomain = sanitize_text_field($_POST['new_domain']);
        foreach ($files as $file) {
            if (file_exists($file)) {
                $content = file_get_contents($file);
                $updated = preg_replace('/(fetch\(["\'])https?:\/\/[^\/]+/', '$1https://' . $newDomain, $content);
                file_put_contents($file, $updated);
            }
        }
        $oldDomain = $newDomain;
        $success = true;
    }

    if (isset($_POST['api_key'])) {
        $postedKey = trim($_POST['api_key']);
        // Save only if key is not empty and not masked
        if ($postedKey !== API_KEY_MASK && $postedKey !== '') {
            update_option('htfy_pusher_api_key', $postedKey);
            $savedApiKey = $postedKey;
            $success = true;
        }
    }
}
?>

<div class="wrap">
    <h2>HTFY API Domain & Key Settings</h2>

    <?php if ($success): ?>
        <div class="notice notice-success is-dismissible"><p>✅ Domain and/or API Key updated successfully.</p></div>
    <?php endif; ?>

    <?php if ($matchFound): ?>
        <form method="POST">
            <table class="form-table">
                <tr>
                    <th><label for="new_domain">API With Domain</label></th>
                    <td><input name="new_domain" type="text" id="new_domain" value="<?= esc_attr($oldDomain) ?>" class="regular-text" required></td>
                </tr>
                <tr>
                    <th><label for="api_key">API Key</label></th>
                    <td>
                      <input name="api_key" type="password" id="api_key" value="" class="regular-text" placeholder="<?= $savedApiKey ? 'API key is saved' : 'Enter API key' ?>">
                      <button type="button" class="button" id="toggle_api" <?= $savedApiKey ? '' : 'style="display:none"' ?>>Show</button>
                      <p class="description">Only update if you want to change the API key.</p>
                    </td>
                </tr>
            </table>
            <p class="submit"><button type="submit" class="button button-primary">Save Settings</button></p>
        </form>
    <?php else: ?>
        <div class="notice notice-error"><p>❌ No fetch domain found in any target files.</p></div>
    <?php endif; ?>
</div>

<script>
document.addEventListener('DOMContentLoaded', () => {
    const apiInput = document.getElementById('api_key');
    const toggleBtn = document.getElementById('toggle_api');
    const realApiKey = <?= json_encode($savedApiKey) ?>;
    const API_KEY_MASK = '<?= API_KEY_MASK ?>';

    let isShowing = false;

    toggleBtn.addEventListener('click', () => {
        if (!isShowing) {
            // Show the real API key as text
            apiInput.type = 'text';
            apiInput.value = realApiKey || '';
            toggleBtn.textContent = 'Hide';
            isShowing = true;
        } else {
            // Hide key and clear input so mask is shown on reload
            apiInput.type = 'password';
            apiInput.value = '';
            toggleBtn.textContent = 'Show';
            isShowing = false;
        }
    });

    apiInput.addEventListener('input', () => {
        // User typing disables toggle button because key is being changed
        if (apiInput.value !== '' && apiInput.value !== realApiKey) {
            toggleBtn.style.display = 'none';
        } else if (realApiKey) {
            toggleBtn.style.display = 'inline-block';
        }
    });
});
</script>
