<?php
if (!current_user_can('manage_options')) {
    wp_die('Unauthorized');
}

$api_key = get_option('htfy_pusher_api_key', '');
?>

<style>
h2 {
    color: #2c3e50;
    font-size: 26px;
    margin-bottom: 20px;
    text-align: center;
}

#totalCount {
    font-weight: bold;
    color: #1e88e5;
    font-size: 36px;
}

label {
    display: block;
    margin: 25px 0 10px;
    font-size: 13px;
    color: #9f9f9f;
}

select {
    width: 100%;
    padding: 12px;
    border: 1px solid #ddd;
    border-radius: 10px;
    font-size: 16px;
    background: #f9f9f9;
    transition: all 0.3s;
}
select:focus {
    border-color: #2196f3;
    background: #fff;
    outline: none;
}

#filteredSection {
    margin-top: 30px;
}

#filterTitle {
    font-size: 20px;
    color: #37474f;
    margin-bottom: 15px;
}

#filterList {
    list-style: none;
    padding: 0;
}

#topicList li {
    padding: 10px;
    list-style: none;
    border-bottom: 1px solid #cfcfcf;
    display: flex;
    align-items: anchor-center;
    justify-content: center;
    gap: 10px;
}

#filterList li:hover {
    background: #e1f0ff;
}

.badge {
    background: #5f5f5f;
    color: #fff;
    font-weight: bold;
    padding: 2px 8px;
    border-radius: 20px;
    font-size: 14px;
}

.btnmenun button {
    padding: 10px 20px;
    margin: 10px 5px;
    background: #795548;
    color: white;
    border: none;
    border-radius: 5px;
    cursor: pointer;
}

.filterdata {
    max-width: 500px;
    display: block;
    padding: 20px;
    box-shadow: 1px 1px 4px 0px #ccc;
    border-radius: 10px;
    margin: 20px auto;
}
#topicTitle {
    margin: 10px auto;
    display: block;
    text-align: center;
    color: #a5a5a5;
    font-size: 22px;
}

#topicList li {
    padding: 10px;
    list-style: none;
    border-bottom: 1px solid #cfcfcf;
}
</style>

<main>
   

    <div class="filterdata">
        <h2><span id="totalCount">Loading...</span></h2>

        <label for="typeSelect"><strong>Topic Type:</strong></label>
        <select id="typeSelect" onchange="updateTopicList()">
            <option value="">-- Select Topic Type --</option>
        </select>

        <div id="topicSection" style="display: none;">
            <h3 id="topicTitle"></h3>
            <ul id="topicList"></ul>
        </div>
    </div>
</main>

<script>
let topicData = null;
let apiKey = <?= json_encode($api_key); ?>;

async function fetchSummary() {
    try {
        const response = await fetch("https://govtjob.website/htfy-pusher/api/get-data-report.php", {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
                "X-API-Key": apiKey
            },
            body: JSON.stringify({})
        });

        const result = await response.json();
        topicData = result;

        const typeSelect = document.getElementById("typeSelect");
        typeSelect.innerHTML = '<option value="">-- Select Topic Type --</option>';  // Reset

        result.topic_types.forEach(type => {
            const option = document.createElement('option');
            option.value = type;
            option.textContent = type.charAt(0).toUpperCase() + type.slice(1);
            typeSelect.appendChild(option);
        });

        document.getElementById("totalCount").textContent = result.total_notifications;

    } catch (error) {
        console.error("Fetch error:", error);
        alert("Error fetching summary data.");
        document.getElementById("totalCount").textContent = "Error";
    }
}

function updateTopicList() {
    const selectedType = document.getElementById("typeSelect").value;
    const topicList = document.getElementById("topicList");
    const topicTitle = document.getElementById("topicTitle");
    const section = document.getElementById("topicSection");

    topicList.innerHTML = "";

    if (!selectedType || !topicData || !topicData.data[selectedType]) {
        section.style.display = "none";
        return;
    }

    const topics = topicData.data[selectedType];
    topics.sort((a, b) => b.total_subscribers - a.total_subscribers);

    topicTitle.textContent = selectedType.charAt(0).toUpperCase() + selectedType.slice(1) + " Wise Summary";

    topics.forEach(item => {
        const li = document.createElement('li');
        const label = item.topic || 'N/A';
        const count = item.total_subscribers || 0;
        li.innerHTML = `<span>${label}</span><span class="badge">${count}</span>`;
        topicList.appendChild(li);
    });

    section.style.display = "block";
}

document.addEventListener('DOMContentLoaded', () => {
    if (!apiKey) {
        alert("❌ API key not found! Please connect API from 'Connect API' tab.");
        return;
    }
    fetchSummary();
});
</script>
