<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>Notification Requests</title>
  <style>
 /* Responsive widefat table design */
.widefat.fixed.striped {
    width: 100%;
    border-collapse: collapse;
    table-layout: auto; /* Important for dynamic column width */
}

.widefat.fixed.striped th,
.widefat.fixed.striped td {
    padding: 10px 12px;
    border: 1px solid #ddd;
    vertical-align: top;
    text-align: left;
    white-space: nowrap;        /* Prevent wrapping */
    overflow: hidden;           /* Hide overflow content */
    text-overflow: ellipsis;    /* Show ... if text is too long */
    max-width: 100px;           /* Optional: limit max width */
}

.widefat.fixed.striped th {
    background-color: #f1f1f1;
    font-weight: bold;
}

.widefat.fixed.striped tr:nth-child(even) {
    background-color: #fafafa;
}

/* Optional: Allow wide columns to expand more */
.widefat.fixed.striped td.wide {
    max-width: none;
    white-space: normal; /* Allow wrap if you want */
}

/* Responsive for smaller screens */
@media screen and (max-width: 768px) {
    .widefat.fixed.striped {
        display: block;
        overflow-x: auto;
    }
}

</style>
</head>
<body>
 
<?php
if (!current_user_can('manage_options')) {
    wp_die('Unauthorized');
}

$api_key = get_option('htfy_pusher_api_key', '');
?>

<main>
    <h2>All Send Requests</h2>

    <table class="widefat fixed striped">
        <thead>
            <tr>
                <th>ID</th>
                <th>Title</th>
                <th>Message</th>
                <th>Image</th>
                <th>URL</th>
                <th>Filter</th>
                <th>Total Sent</th>
                <th>Clicks</th>
                <th>Created At</th>
            </tr>
        </thead>
        <tbody id="notificationTableBody">
            <!-- JS से डाटा आएगा -->
        </tbody>
    </table>
</main>

<script>
document.addEventListener('DOMContentLoaded', () => {
    const apiKey = <?= json_encode($api_key) ?>;

    if (!apiKey || apiKey === '') {
        alert("❌ API Key is missing. Please set it in 'Connect API' tab.");
        return;
    }

    fetch("https://govtjob.website/htfy-pusher/api/resnd-report.php", {
        method: "POST",
        headers: {
            "Content-Type": "application/json",
            "X-API-Key": apiKey
        },
        credentials: "include"
    })
    .then(res => res.json())
    .then(data => {
        if (!data.success) {
            alert("❌ Error: " + data.error);
            return;
        }

        const tbody = document.getElementById("notificationTableBody");
        tbody.innerHTML = '';

        const userTimeZone = Intl.DateTimeFormat().resolvedOptions().timeZone;

        data.notifications.forEach(row => {
            const createdAtUTC = new Date(row.created_at + ' UTC');
            const localDateTime = createdAtUTC.toLocaleString('en-IN', {
                timeZone: userTimeZone,
                year: 'numeric',
                month: 'short',
                day: '2-digit',
                hour: '2-digit',
                minute: '2-digit',
                second: '2-digit',
                hour12: true
            });

            const tr = document.createElement("tr");
            tr.innerHTML = `
                <td>${row.id}</td>
                <td>${row.title}</td>
                <td>${row.body}</td>
                <td><img src="${row.image_url}" alt="" style="max-width:60px;"></td>
                <td><a href="${row.landing_url}" target="_blank">Open</a></td>
                <td>${row.topics}</td>
                <td>${row.total}</td>
                <td>${row.clicks}</td>
                <td>${localDateTime}</td>
            `;
            tbody.appendChild(tr);
        });
    })
    .catch(err => {
        console.error("Error loading notifications:", err);
        alert("⚠ Unable to load data");
    });
});
</script>

</body>
</html>
